@@ -32,7 +32,7 @@
 #include <string.h>
 #include <unistd.h>
 
-#include <sys/types.h>	/* Apollo/DomainOS needs this _before_ sys/stat.h */
+#include <sys/types.h>		/* Apollo/DomainOS needs this _before_ sys/stat.h */
 #include <sys/stat.h>
 
 #include "gtkglue.h"
@@ -47,8 +47,7 @@
 #define DBG_info 3
 #define DBG_debug 4
 
-#define DEBUG_NOT_STATIC
-#define BACKEND_NAME xscanimage
+#define BACKEND_NAME gtkglue
 #include "../include/sane/sanei_debug.h"
 
 int gsg_message_dialog_active = 0;
@@ -63,11 +62,16 @@ unit_string (SANE_Unit unit)
 
   switch (unit)
     {
-    case SANE_UNIT_NONE:	return "none";
-    case SANE_UNIT_PIXEL:	return "pixel";
-    case SANE_UNIT_BIT:		return "bit";
-    case SANE_UNIT_DPI:		return "dpi";
-    case SANE_UNIT_PERCENT:	return "%";
+    case SANE_UNIT_NONE:
+      return "none";
+    case SANE_UNIT_PIXEL:
+      return "pixel";
+    case SANE_UNIT_BIT:
+      return "bit";
+    case SANE_UNIT_DPI:
+      return "dpi";
+    case SANE_UNIT_PERCENT:
+      return "%";
     case SANE_UNIT_MM:
       d = preferences.length_unit;
       if (d > 9.9 && d < 10.1)
@@ -75,13 +79,14 @@ unit_string (SANE_Unit unit)
       else if (d > 25.3 && d < 25.5)
 	return "in";
       return "mm";
-    case SANE_UNIT_MICROSECOND:	return "us";
+    case SANE_UNIT_MICROSECOND:
+      return "us";
     }
   return 0;
 }
 
 static void
-set_tooltip (GtkTooltips *tooltips, GtkWidget *widget, const char *desc)
+set_tooltip (GtkTooltips * tooltips, GtkWidget * widget, const char *desc)
 {
   if (desc && desc[0])
 #ifdef HAVE_GTK_TOOLTIPS_SET_TIPS
@@ -95,8 +100,7 @@ set_tooltip (GtkTooltips *tooltips, GtkWidget *widget, const char *desc)
 int
 gsg_make_path (size_t buf_size, char *buf,
 	       const char *prog_name,
-	       const char *prefix, const char *dev_name,
-	       const char *postfix)
+	       const char *prefix, const char *dev_name, const char *postfix)
 {
   struct passwd *pw;
   size_t len, extra;
@@ -112,7 +116,7 @@ gsg_make_path (size_t buf_size, char *buf,
       return -1;
     }
   snprintf (buf, buf_size, "%s/.sane", pw->pw_dir);
-  mkdir (buf, 0777);	/* ensure ~/.sane directory exists */
+  mkdir (buf, 0777);		/* ensure ~/.sane directory exists */
 
   len = strlen (buf);
 
@@ -146,8 +150,8 @@ gsg_make_path (size_t buf_size, char *buf,
   if (dev_name)
     {
       /* Turn devicename into valid filename by replacing slashes by
-	 "+-".  A lonely `+' gets translated into "++" so we can tell
-	 it from a substituted slash.  */
+         "+-".  A lonely `+' gets translated into "++" so we can tell
+         it from a substituted slash.  */
 
       for (i = 0; dev_name[i]; ++i)
 	{
@@ -162,7 +166,7 @@ gsg_make_path (size_t buf_size, char *buf,
 	      break;
 
 #ifdef HAVE_OS2_H
-	    case ':': /* OS2 can not handle colons in filenames */
+	    case ':':		/* OS2 can not handle colons in filenames */
 	      buf[len++] = '+';
 	      buf[len++] = '_';
 	      break;
@@ -208,8 +212,8 @@ set_option (GSGDialog * dialog, int opt_num, void *val, SANE_Action action)
   if (status != SANE_STATUS_GOOD)
     {
       snprintf (buf, sizeof (buf), "Failed to set value of option %s: %s.",
-	       sane_get_option_descriptor (dialog->dev, opt_num)->name,
-	       sane_strstatus (status));
+		sane_get_option_descriptor (dialog->dev, opt_num)->name,
+		sane_strstatus (status));
       gsg_error (buf);
       return;
     }
@@ -231,7 +235,7 @@ gsg_close_dialog_callback (GtkWidget * widget, gpointer data)
 }
 
 void
-gsg_message (gchar *title, gchar *message)
+gsg_message (gchar * title, gchar * message)
 {
   GtkWidget *main_vbox, *label;
   GtkWidget *button, *message_dialog;
@@ -282,7 +286,7 @@ gsg_warning (gchar * warning)
 }
 
 static void
-get_filename_button_clicked (GtkWidget *w, gpointer data)
+get_filename_button_clicked (GtkWidget * w, gpointer data)
 {
   int *clicked = data;
   *clicked = 1;
@@ -297,9 +301,10 @@ gsg_get_filename (const char *label, const char *default_name,
 
   filesel = gtk_file_selection_new ((char *) label);
 
-  gtk_window_set_modal(GTK_WINDOW(filesel), TRUE);
+  gtk_window_set_modal (GTK_WINDOW (filesel), TRUE);
 
-  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
+  gtk_signal_connect (GTK_OBJECT
+		      (GTK_FILE_SELECTION (filesel)->cancel_button),
 		      "clicked", (GtkSignalFunc) get_filename_button_clicked,
 		      &cancel);
   gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
@@ -371,8 +376,8 @@ autobutton_update (GtkWidget * widget, GSGDialogElement * elem)
 }
 
 static void
-autobutton_new (GtkWidget *parent, GSGDialogElement *elem,
-		GtkWidget *label, GtkTooltips *tooltips)
+autobutton_new (GtkWidget * parent, GSGDialogElement * elem,
+		GtkWidget * label, GtkTooltips * tooltips)
 {
   GtkWidget *button, *alignment;
 
@@ -380,8 +385,7 @@ autobutton_new (GtkWidget *parent, GSGDialogElement *elem,
   gtk_container_border_width (GTK_CONTAINER (button), 0);
   gtk_widget_set_usize (button, 20, 20);
   gtk_signal_connect (GTK_OBJECT (button), "toggled",
-		      (GtkSignalFunc) autobutton_update,
-		      elem);
+		      (GtkSignalFunc) autobutton_update, elem);
   set_tooltip (tooltips, button, "Turns on automatic mode.");
 
   alignment = gtk_alignment_new (0.0, 1.0, 0.5, 0.5);
@@ -411,7 +415,7 @@ button_update (GtkWidget * widget, GSGDialogElement * elem)
 
 static void
 button_new (GtkWidget * parent, const char *name, SANE_Word val,
-	    GSGDialogElement * elem, GtkTooltips *tooltips, const char *desc,
+	    GSGDialogElement * elem, GtkTooltips * tooltips, const char *desc,
 	    gint is_settable)
 {
   GtkWidget *button;
@@ -419,8 +423,7 @@ button_new (GtkWidget * parent, const char *name, SANE_Word val,
   button = gtk_check_button_new_with_label ((char *) name);
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), val);
   gtk_signal_connect (GTK_OBJECT (button), "toggled",
-		      (GtkSignalFunc) button_update,
-		      elem);
+		      (GtkSignalFunc) button_update, elem);
   gtk_box_pack_start (GTK_BOX (parent), button, FALSE, TRUE, 0);
   if (!is_settable)
     gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
@@ -440,6 +443,11 @@ scale_update (GtkAdjustment * adj_data, GSGDialogElement * elem)
   double d;
   SANE_Status status;
 
+  DBG_INIT ();
+
+  DBG (DBG_debug, "scale_update\n");
+
+
   opt_num = elem - dialog->element;
   opt = sane_get_option_descriptor (dialog->dev, opt_num);
   switch (opt->type)
@@ -460,11 +468,13 @@ scale_update (GtkAdjustment * adj_data, GSGDialogElement * elem)
       return;
     }
   set_option (dialog, opt_num, &val, SANE_ACTION_SET_VALUE);
-  status = sane_control_option (dialog->dev, opt_num, SANE_ACTION_GET_VALUE, &new_val,
-				0);
+  status =
+    sane_control_option (dialog->dev, opt_num, SANE_ACTION_GET_VALUE,
+			 &new_val, 0);
   if (status != SANE_STATUS_GOOD)
     {
-      DBG (DBG_fatal, "scale_update: sane_control_option failed: %s\n", sane_strstatus (status));
+      DBG (DBG_fatal, "scale_update: sane_control_option failed: %s\n",
+	   sane_strstatus (status));
       return;
     }
 
@@ -502,7 +512,7 @@ value_changed:
 static void
 scale_new (GtkWidget * parent, const char *name, gfloat val,
 	   gfloat min, gfloat max, gfloat quant, int automatic,
-	   GSGDialogElement * elem, GtkTooltips *tooltips, const char *desc,
+	   GSGDialogElement * elem, GtkTooltips * tooltips, const char *desc,
 	   gint is_settable)
 {
   GtkWidget *hbox, *label, *scale;
@@ -603,10 +613,9 @@ option_menu_callback (GtkWidget * widget, gpointer data)
 }
 
 static void
-option_menu_new (GtkWidget *parent, const char *name, char *str_list[],
+option_menu_new (GtkWidget * parent, const char *name, char *str_list[],
 		 const char *val, GSGDialogElement * elem,
-		 GtkTooltips *tooltips, const char *desc,
-		 gint is_settable)
+		 GtkTooltips * tooltips, const char *desc, gint is_settable)
 {
   GtkWidget *hbox, *label, *option_menu, *menu, *item;
   GSGMenuItem *menu_items;
@@ -657,7 +666,7 @@ option_menu_new (GtkWidget *parent, const char *name, char *str_list[],
 }
 
 static void
-text_entry_callback (GtkWidget *w, gpointer data)
+text_entry_callback (GtkWidget * w, gpointer data)
 {
   GSGDialogElement *elem = data;
   const SANE_Option_Descriptor *opt;
@@ -687,8 +696,7 @@ text_entry_callback (GtkWidget *w, gpointer data)
 static void
 text_entry_new (GtkWidget * parent, const char *name, const char *val,
 		GSGDialogElement * elem,
-		GtkTooltips *tooltips, const char *desc, 
-		gint is_settable)
+		GtkTooltips * tooltips, const char *desc, gint is_settable)
 {
   GtkWidget *hbox, *text, *label;
 
@@ -716,9 +724,9 @@ text_entry_new (GtkWidget * parent, const char *name, const char *val,
 }
 
 static GtkWidget *
-group_new (GtkWidget *parent, const char * title)
+group_new (GtkWidget * parent, const char *title)
 {
-  GtkWidget * frame, * vbox;
+  GtkWidget *frame, *vbox;
 
   frame = gtk_frame_new ((char *) title);
   gtk_container_border_width (GTK_CONTAINER (frame), 4);
@@ -732,10 +740,10 @@ group_new (GtkWidget *parent, const char * title)
   return vbox;
 }
 
-static GtkWidget*
-curve_new (GSGDialog *dialog, int optnum)
+static GtkWidget *
+curve_new (GSGDialog * dialog, int optnum)
 {
-  const SANE_Option_Descriptor * opt;
+  const SANE_Option_Descriptor *opt;
   gfloat fmin, fmax, val, *vector;
   SANE_Word *optval, min, max;
   GtkWidget *curve, *gamma;
@@ -747,7 +755,7 @@ curve_new (GSGDialog *dialog, int optnum)
   curve = GTK_GAMMA_CURVE (gamma)->curve;
   dev = dialog->dev;
 
-  opt    = sane_get_option_descriptor (dev, optnum);
+  opt = sane_get_option_descriptor (dev, optnum);
   optlen = opt->size / sizeof (SANE_Word);
   vector = alloca (optlen * (sizeof (vector[0]) + sizeof (optval[0])));
   optval = (SANE_Word *) (vector + optlen);
@@ -818,7 +826,7 @@ curve_new (GSGDialog *dialog, int optnum)
 }
 
 static void
-vector_new (GSGDialog * dialog, GtkWidget *vbox, int num_vopts, int *vopts)
+vector_new (GSGDialog * dialog, GtkWidget * vbox, int num_vopts, int *vopts)
 {
   GtkWidget *notebook, *label, *curve;
   const SANE_Option_Descriptor *opt;
@@ -833,7 +841,7 @@ vector_new (GSGDialog * dialog, GtkWidget *vbox, int num_vopts, int *vopts)
       opt = sane_get_option_descriptor (dialog->dev, vopts[i]);
 
       label = gtk_label_new ((char *) opt->title);
-      vbox = gtk_vbox_new (/* homogeneous */ FALSE, 0);
+      vbox = gtk_vbox_new ( /* homogeneous */ FALSE, 0);
       gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
       gtk_widget_show (vbox);
       gtk_widget_show (label);
@@ -863,7 +871,7 @@ panel_destroy (GSGDialog * dialog)
   gtk_object_sink (GTK_OBJECT (dialog->tooltips));
 # else
   gtk_object_unref (GTK_OBJECT (dialog->tooltips));
-# endif /* GTK_MAJOR_VERSION == 2 */
+# endif	/* GTK_MAJOR_VERSION == 2 */
 #endif
   gtk_widget_destroy (dialog->main_hbox);
 
@@ -886,7 +894,7 @@ panel_destroy (GSGDialog * dialog)
 	}
     }
   memset (dialog->element, 0,
-	  dialog->num_elements*sizeof (dialog->element[0]));
+	  dialog->num_elements * sizeof (dialog->element[0]));
 }
 
 static void
@@ -907,40 +915,40 @@ panel_build (GSGDialog * dialog)
   int num_vector_opts = 0, *vector_opts;
 
   main_hbox = gtk_hbox_new (FALSE, 2);
- 
+
   if (dialog->twocolumn)
-     { 
-       option_vbox = gtk_hbox_new (FALSE, 2);  /* two column display */
-     }
-   else
-     {
-       option_vbox = gtk_vbox_new (FALSE, 2);  /* one column display */
-     }
+    {
+      option_vbox = gtk_hbox_new (FALSE, 2);	/* two column display */
+    }
+  else
+    {
+      option_vbox = gtk_vbox_new (FALSE, 2);	/* one column display */
+    }
 
   gtk_box_pack_start (GTK_BOX (main_hbox), option_vbox, FALSE, FALSE, 0);
   gtk_widget_show (option_vbox);
 
   /* standard options vbox */
 
-  standard_vbox = gtk_vbox_new (/* homogeneous */ FALSE, 0);
+  standard_vbox = gtk_vbox_new ( /* homogeneous */ FALSE, 0);
   gtk_widget_show (standard_vbox);
   gtk_box_pack_start (GTK_BOX (option_vbox), standard_vbox, FALSE, FALSE, 0);
 
   /* advanced options page */
 
-  advanced_vbox = gtk_vbox_new (/* homogeneous */ FALSE, 0);
+  advanced_vbox = gtk_vbox_new ( /* homogeneous */ FALSE, 0);
   gtk_box_pack_start (GTK_BOX (option_vbox), advanced_vbox, TRUE, TRUE, 0);
 
   /* use black as foreground: */
   dialog->tooltips = gtk_tooltips_new ();
-  dialog->tooltips_fg.red   = 0;
+  dialog->tooltips_fg.red = 0;
   dialog->tooltips_fg.green = 0;
-  dialog->tooltips_fg.blue  = 0;
+  dialog->tooltips_fg.blue = 0;
   /* postit yellow (khaki) as background: */
   gdk_color_alloc (gtk_widget_get_colormap (main_hbox), &dialog->tooltips_fg);
-  dialog->tooltips_bg.red   = 61669;
+  dialog->tooltips_bg.red = 61669;
   dialog->tooltips_bg.green = 59113;
-  dialog->tooltips_bg.blue  = 35979;
+  dialog->tooltips_bg.blue = 35979;
   gdk_color_alloc (gtk_widget_get_colormap (main_hbox), &dialog->tooltips_bg);
 
   /* GTK2 doesn't have the function (seems like it's not needed with GTK2 anyway) */
@@ -1027,7 +1035,7 @@ panel_build (GSGDialog * dialog)
 	    goto get_value_failed;
 
 	  button_new (parent, title, val, elem, dialog->tooltips, opt->desc,
-		      SANE_OPTION_IS_SETTABLE(opt->cap));
+		      SANE_OPTION_IS_SETTABLE (opt->cap));
 	  gtk_widget_show (parent->parent);
 	  break;
 
@@ -1058,7 +1066,7 @@ panel_build (GSGDialog * dialog)
 			 opt->constraint.range->max, quant,
 			 (opt->cap & SANE_CAP_AUTOMATIC), elem,
 			 dialog->tooltips, opt->desc,
-			 SANE_OPTION_IS_SETTABLE(opt->cap));
+			 SANE_OPTION_IS_SETTABLE (opt->cap));
 	      gtk_widget_show (parent->parent);
 	      break;
 
@@ -1075,14 +1083,14 @@ panel_build (GSGDialog * dialog)
 	      sprintf (str, "%d", val);
 	      option_menu_new (parent, title, str_list, str, elem,
 			       dialog->tooltips, opt->desc,
-			       SANE_OPTION_IS_SETTABLE(opt->cap));
+			       SANE_OPTION_IS_SETTABLE (opt->cap));
 	      free (str_list);
 	      gtk_widget_show (parent->parent);
 	      break;
 
 	    case SANE_CONSTRAINT_NONE:
 	      /* having no constraint for an int is strange but allowed
-		 by the SANE standard so we just ignore such options here */
+	         by the SANE standard so we just ignore such options here */
 	      break;
 
 	    default:
@@ -1128,7 +1136,7 @@ panel_build (GSGDialog * dialog)
 	      scale_new (parent, title, dval, dmin, dmax, dquant,
 			 (opt->cap & SANE_CAP_AUTOMATIC), elem,
 			 dialog->tooltips, opt->desc,
-			 SANE_OPTION_IS_SETTABLE(opt->cap));
+			 SANE_OPTION_IS_SETTABLE (opt->cap));
 	      gtk_widget_show (parent->parent);
 	      break;
 
@@ -1146,14 +1154,14 @@ panel_build (GSGDialog * dialog)
 	      sprintf (str, "%g", SANE_UNFIX (val));
 	      option_menu_new (parent, title, str_list, str, elem,
 			       dialog->tooltips, opt->desc,
-			       SANE_OPTION_IS_SETTABLE(opt->cap));
+			       SANE_OPTION_IS_SETTABLE (opt->cap));
 	      free (str_list);
 	      gtk_widget_show (parent->parent);
 	      break;
 
 	    case SANE_CONSTRAINT_NONE:
 	      /* having no constraint for a fixed is strange but allowed
-		 by the SANE standard so we just ignore such options here */
+	         by the SANE standard so we just ignore such options here */
 	      break;
 
 	    default:
@@ -1184,14 +1192,14 @@ panel_build (GSGDialog * dialog)
 	      option_menu_new (parent, title,
 			       (char **) opt->constraint.string_list, buf,
 			       elem, dialog->tooltips, opt->desc,
-			       SANE_OPTION_IS_SETTABLE(opt->cap));
+			       SANE_OPTION_IS_SETTABLE (opt->cap));
 	      gtk_widget_show (parent->parent);
 	      break;
 
 	    case SANE_CONSTRAINT_NONE:
 	      text_entry_new (parent, title, buf, elem,
 			      dialog->tooltips, opt->desc,
-			      SANE_OPTION_IS_SETTABLE(opt->cap));
+			      SANE_OPTION_IS_SETTABLE (opt->cap));
 	      gtk_widget_show (parent->parent);
 	      break;
 
@@ -1265,8 +1273,9 @@ panel_rebuild (GSGDialog * dialog)
 
 GSGDialog *
 gsg_create_dialog (GtkWidget * window, const char *device_name,
-		   GSGCallback option_reload_callback, void *option_reload_arg,
-		   GSGCallback param_change_callback, void *param_change_arg)
+		   GSGCallback option_reload_callback,
+		   void *option_reload_arg, GSGCallback param_change_callback,
+		   void *param_change_arg)
 {
   SANE_Int num_elements;
   GSGDialog *dialog;
@@ -1313,7 +1322,7 @@ gsg_create_dialog (GtkWidget * window, const char *device_name,
 }
 
 void
-gsg_refresh_dialog (GSGDialog *dialog)
+gsg_refresh_dialog (GSGDialog * dialog)
 {
   panel_rebuild (dialog);
   if (dialog->param_change_callback)
@@ -1321,7 +1330,7 @@ gsg_refresh_dialog (GSGDialog *dialog)
 }
 
 void
-gsg_update_scan_window (GSGDialog *dialog)
+gsg_update_scan_window (GSGDialog * dialog)
 {
   const SANE_Option_Descriptor *opt;
   double old_val, new_val;
@@ -1339,10 +1348,9 @@ gsg_update_scan_window (GSGDialog *dialog)
 	opt = sane_get_option_descriptor (dialog->dev, optnum);
 
 	status = sane_control_option (dialog->dev, optnum,
-				      SANE_ACTION_GET_VALUE,
-				      &word, 0);
+				      SANE_ACTION_GET_VALUE, &word, 0);
 	if (status != SANE_STATUS_GOOD)
-	  continue;	/* sliently ignore errors */
+	  continue;		/* sliently ignore errors */
 
 	switch (opt->constraint_type)
 	  {
@@ -1373,7 +1381,8 @@ gsg_update_scan_window (GSGDialog *dialog)
 	      sprintf (str, "%g", SANE_UNFIX (word));
 	    /* XXX maybe we should call this only when the value changes... */
 	    gtk_option_menu_set_history (GTK_OPTION_MENU (elem->widget),
-					 option_menu_lookup (elem->menu, str));
+					 option_menu_lookup (elem->menu,
+							     str));
 	    break;
 
 	  default:
@@ -1386,7 +1395,7 @@ gsg_update_scan_window (GSGDialog *dialog)
    vectors, all option values are kept current.  Vectors are
    downloaded into the device during this call.  */
 void
-gsg_sync (GSGDialog *dialog)
+gsg_sync (GSGDialog * dialog)
 {
   const SANE_Option_Descriptor *opt;
   gfloat val, *vector;
@@ -1400,8 +1409,7 @@ gsg_sync (GSGDialog *dialog)
       if (!SANE_OPTION_IS_ACTIVE (opt->cap))
 	continue;
 
-      if (opt->type != SANE_TYPE_INT &&
-	  opt->type != SANE_TYPE_FIXED)
+      if (opt->type != SANE_TYPE_INT && opt->type != SANE_TYPE_FIXED)
 	continue;
 
       if (opt->size == sizeof (SANE_Word))
@@ -1429,14 +1437,14 @@ gsg_sync (GSGDialog *dialog)
 }
 
 void
-gsg_set_advanced (GSGDialog *dialog, int advanced)
+gsg_set_advanced (GSGDialog * dialog, int advanced)
 {
   dialog->advanced = advanced;
   panel_rebuild (dialog);
 }
 
 void
-gsg_set_tooltips (GSGDialog *dialog, int enable)
+gsg_set_tooltips (GSGDialog * dialog, int enable)
 {
   if (!dialog->tooltips)
     return;
@@ -1448,14 +1456,14 @@ gsg_set_tooltips (GSGDialog *dialog, int enable)
 }
 
 void
-gsg_set_twocolumn (GSGDialog *dialog, int twocolumn)
+gsg_set_twocolumn (GSGDialog * dialog, int twocolumn)
 {
   dialog->twocolumn = twocolumn;
-       panel_rebuild (dialog);
+  panel_rebuild (dialog);
 }
 
 void
-gsg_set_sensitivity (GSGDialog *dialog, int sensitive)
+gsg_set_sensitivity (GSGDialog * dialog, int sensitive)
 {
   const SANE_Option_Descriptor *opt;
   int i;
@@ -1465,8 +1473,7 @@ gsg_set_sensitivity (GSGDialog *dialog, int sensitive)
       opt = sane_get_option_descriptor (dialog->dev, i);
 
       if (!SANE_OPTION_IS_ACTIVE (opt->cap)
-	  || opt->type == SANE_TYPE_GROUP
-	  || !dialog->element[i].widget)
+	  || opt->type == SANE_TYPE_GROUP || !dialog->element[i].widget)
 	continue;
 
       if (!(opt->cap & SANE_CAP_ALWAYS_SETTABLE))
