@@ -85,8 +85,7 @@
 #define DBG_info 3
 #define DBG_debug 4
 
-#define DEBUG_DECLARE_ONLY
-#define BACKEND_NAME xscanimage
+#define BACKEND_NAME preview
 #include "../include/sane/sanei_debug.h"
 
 #ifndef PATH_MAX
@@ -111,11 +110,11 @@
 #endif
 
 /* forward declarations */
-static void scan_start (Preview *p);
-static void scan_done (Preview *p);
+static void scan_start (Preview * p);
+static void scan_done (Preview * p);
 
 static void
-draw_rect (GdkWindow *win, GdkGC *gc, int coord[4])
+draw_rect (GdkWindow * win, GdkGC * gc, int coord[4])
 {
   gint x, y, w, h;
 
@@ -137,7 +136,7 @@ draw_rect (GdkWindow *win, GdkGC *gc, int coord[4])
 }
 
 static void
-draw_selection (Preview *p)
+draw_selection (Preview * p)
 {
   if (!p->gc)
     /* window isn't mapped yet */
@@ -153,7 +152,7 @@ draw_selection (Preview *p)
 }
 
 static void
-update_selection (Preview *p)
+update_selection (Preview * p)
 {
   float min, max, normal, dev_selection[4];
   const SANE_Option_Descriptor *opt;
@@ -192,8 +191,9 @@ update_selection (Preview *p)
       normal = ((i == 0) ? p->preview_width : p->preview_height) - 1;
       normal /= (max - min);
       p->selection.active = TRUE;
-      p->selection.coord[i]     = ((dev_selection[i] - min)*normal) + 0.5;
-      p->selection.coord[i + 2] = ((dev_selection[i + 2] - min)*normal) + 0.5;
+      p->selection.coord[i] = ((dev_selection[i] - min) * normal) + 0.5;
+      p->selection.coord[i + 2] =
+	((dev_selection[i + 2] - min) * normal) + 0.5;
       if (p->selection.coord[i + 2] < p->selection.coord[i])
 	p->selection.coord[i + 2] = p->selection.coord[i];
     }
@@ -201,7 +201,7 @@ update_selection (Preview *p)
 }
 
 static void
-get_image_scale (Preview *p, float *xscalep, float *yscalep)
+get_image_scale (Preview * p, float *xscalep, float *yscalep)
 {
   float xscale, yscale;
 
@@ -209,9 +209,9 @@ get_image_scale (Preview *p, float *xscalep, float *yscalep)
     xscale = 1.0;
   else
     {
-      xscale = p->image_width/(float) p->preview_width;
-      if (p->image_height > 0 && p->preview_height*xscale < p->image_height)
-	xscale = p->image_height/(float) p->preview_height;
+      xscale = p->image_width / (float) p->preview_width;
+      if (p->image_height > 0 && p->preview_height * xscale < p->image_height)
+	xscale = p->image_height / (float) p->preview_height;
     }
   yscale = xscale;
 
@@ -222,32 +222,32 @@ get_image_scale (Preview *p, float *xscalep, float *yscalep)
       float swidth, sheight;
 
       assert (p->surface_type == SANE_TYPE_INT);
-      swidth  = (p->surface[GSG_BR_X] - p->surface[GSG_TL_X] + 1);
+      swidth = (p->surface[GSG_BR_X] - p->surface[GSG_TL_X] + 1);
       sheight = (p->surface[GSG_BR_Y] - p->surface[GSG_TL_Y] + 1);
       xscale = 1.0;
       yscale = 1.0;
       if (p->image_width > 0 && swidth < INF)
-	xscale = p->image_width/swidth;
+	xscale = p->image_width / swidth;
       if (p->image_height > 0 && sheight < INF)
-	yscale = p->image_height/sheight;
+	yscale = p->image_height / sheight;
     }
   *xscalep = xscale;
   *yscalep = yscale;
 }
 
 static void
-paint_image (Preview *p)
+paint_image (Preview * p)
 {
   float xscale, yscale, src_x, src_y;
   int dst_x, dst_y, height, x, y, src_offset;
   gint gwidth, gheight;
 
-  gwidth  = p->preview_width;
+  gwidth = p->preview_width;
   gheight = p->preview_height;
 
   get_image_scale (p, &xscale, &yscale);
 
-  memset (p->preview_row, 0xff, 3*gwidth);
+  memset (p->preview_row, 0xff, 3 * gwidth);
 
   /* don't draw last line unless it's complete: */
   height = p->image_y;
@@ -262,7 +262,7 @@ paint_image (Preview *p)
       y = (int) (src_y + 0.5);
       if (y >= height)
 	break;
-      src_offset = y*3*p->image_width;
+      src_offset = y * 3 * p->image_width;
 
       if (p->image_data)
 	for (dst_x = 0; dst_x < gwidth; ++dst_x)
@@ -271,9 +271,12 @@ paint_image (Preview *p)
 	    if (x >= p->image_width)
 	      break;
 
-	    p->preview_row[3*dst_x + 0] = p->image_data[src_offset + 3*x + 0];
-	    p->preview_row[3*dst_x + 1] = p->image_data[src_offset + 3*x + 1];
-	    p->preview_row[3*dst_x + 2] = p->image_data[src_offset + 3*x + 2];
+	    p->preview_row[3 * dst_x + 0] =
+	      p->image_data[src_offset + 3 * x + 0];
+	    p->preview_row[3 * dst_x + 1] =
+	      p->image_data[src_offset + 3 * x + 1];
+	    p->preview_row[3 * dst_x + 2] =
+	      p->image_data[src_offset + 3 * x + 2];
 	    src_x += xscale;
 	  }
       gtk_preview_draw_row (GTK_PREVIEW (p->window), p->preview_row,
@@ -284,7 +287,7 @@ paint_image (Preview *p)
 }
 
 static void
-display_partial_image (Preview *p)
+display_partial_image (Preview * p)
 {
   paint_image (p);
 
@@ -293,8 +296,8 @@ display_partial_image (Preview *p)
       GtkPreview *preview = GTK_PREVIEW (p->window);
       int src_x, src_y;
 
-      src_x = (p->window->allocation.width - preview->buffer_width)/2;
-      src_y = (p->window->allocation.height - preview->buffer_height)/2;
+      src_x = (p->window->allocation.width - preview->buffer_width) / 2;
+      src_y = (p->window->allocation.height - preview->buffer_height) / 2;
       gtk_preview_put (preview, p->window->window, p->window->style->black_gc,
 		       src_x, src_y,
 		       0, 0, p->preview_width, p->preview_height);
@@ -302,7 +305,7 @@ display_partial_image (Preview *p)
 }
 
 static void
-display_maybe (Preview *p)
+display_maybe (Preview * p)
 {
   time_t now;
 
@@ -315,13 +318,13 @@ display_maybe (Preview *p)
 }
 
 static void
-display_image (Preview *p)
+display_image (Preview * p)
 {
   if (p->params.lines <= 0 && p->image_y < p->image_height)
     {
       p->image_height = p->image_y;
       p->image_data = realloc (p->image_data,
-			       3*p->image_width*p->image_height);
+			       3 * p->image_width * p->image_height);
       assert (p->image_data);
     }
   display_partial_image (p);
@@ -329,20 +332,20 @@ display_image (Preview *p)
 }
 
 static void
-preview_area_resize (GtkWidget *widget)
+preview_area_resize (GtkWidget * widget)
 {
   float min_x, max_x, min_y, max_y, xscale, yscale, f;
   Preview *p;
 
   p = gtk_object_get_data (GTK_OBJECT (widget), "PreviewPointer");
 
-  p->preview_width  = widget->allocation.width;
+  p->preview_width = widget->allocation.width;
   p->preview_height = widget->allocation.height;
 
   if (p->preview_row)
-    p->preview_row = realloc (p->preview_row, 3*p->preview_width);
+    p->preview_row = realloc (p->preview_row, 3 * p->preview_width);
   else
-    p->preview_row = malloc (3*p->preview_width);
+    p->preview_row = malloc (3 * p->preview_width);
 
   /* set the ruler ranges: */
 
@@ -351,7 +354,7 @@ preview_area_resize (GtkWidget *widget)
     min_x = 0.0;
 
   max_x = p->surface[GSG_BR_X];
-  if (max_x >=  INF)
+  if (max_x >= INF)
     max_x = p->preview_width - 1;
 
   min_y = p->surface[GSG_TL_Y];
@@ -359,35 +362,38 @@ preview_area_resize (GtkWidget *widget)
     min_y = 0.0;
 
   max_y = p->surface[GSG_BR_Y];
-  if (max_y >=  INF)
+  if (max_y >= INF)
     max_y = p->preview_height - 1;
 
   /* convert mm to inches if that's what the user wants: */
 
   if (p->surface_unit == SANE_UNIT_MM)
     {
-      double factor = 1.0/preferences.length_unit;
-      min_x *= factor; max_x *= factor; min_y *= factor; max_y *= factor;
+      double factor = 1.0 / preferences.length_unit;
+      min_x *= factor;
+      max_x *= factor;
+      min_y *= factor;
+      max_y *= factor;
     }
 
   get_image_scale (p, &xscale, &yscale);
 
   if (p->surface_unit == SANE_UNIT_PIXEL)
-    f = 1.0/xscale;
+    f = 1.0 / xscale;
   else if (p->image_width)
-    f = xscale*p->preview_width/p->image_width;
+    f = xscale * p->preview_width / p->image_width;
   else
     f = 1.0;
-  gtk_ruler_set_range (GTK_RULER (p->hruler), f*min_x, f*max_x, f*min_x,
+  gtk_ruler_set_range (GTK_RULER (p->hruler), f * min_x, f * max_x, f * min_x,
 		       /* max_size */ 20);
 
   if (p->surface_unit == SANE_UNIT_PIXEL)
-    f = 1.0/yscale;
+    f = 1.0 / yscale;
   else if (p->image_height)
-    f = yscale*p->preview_height/p->image_height;
+    f = yscale * p->preview_height / p->image_height;
   else
     f = 1.0;
-  gtk_ruler_set_range (GTK_RULER (p->vruler), f*min_y, f*max_y, f*min_y,
+  gtk_ruler_set_range (GTK_RULER (p->vruler), f * min_y, f * max_y, f * min_y,
 		       /* max_size */ 20);
 
   paint_image (p);
@@ -395,13 +401,13 @@ preview_area_resize (GtkWidget *widget)
 }
 
 static void
-get_bounds (const SANE_Option_Descriptor *opt, float *minp, float *maxp)
+get_bounds (const SANE_Option_Descriptor * opt, float *minp, float *maxp)
 {
   float min, max;
   int i;
 
   min = -INF;
-  max =  INF;
+  max = INF;
   switch (opt->constraint_type)
     {
     case SANE_CONSTRAINT_RANGE:
@@ -410,7 +416,7 @@ get_bounds (const SANE_Option_Descriptor *opt, float *minp, float *maxp)
       break;
 
     case SANE_CONSTRAINT_WORD_LIST:
-      min =  INF;
+      min = INF;
       max = -INF;
       for (i = 1; i <= opt->constraint.word_list[0]; ++i)
 	{
@@ -436,7 +442,7 @@ get_bounds (const SANE_Option_Descriptor *opt, float *minp, float *maxp)
 }
 
 static void
-save_option (Preview *p, int option, SANE_Word *save_loc, int *valid)
+save_option (Preview * p, int option, SANE_Word * save_loc, int *valid)
 {
   SANE_Status status;
 
@@ -451,7 +457,7 @@ save_option (Preview *p, int option, SANE_Word *save_loc, int *valid)
 }
 
 static void
-restore_option (Preview *p, int option, SANE_Word saved_value, int valid)
+restore_option (Preview * p, int option, SANE_Word saved_value, int valid)
 {
   const SANE_Option_Descriptor *opt;
   SANE_Status status;
@@ -474,7 +480,7 @@ restore_option (Preview *p, int option, SANE_Word saved_value, int valid)
 }
 
 static SANE_Status
-set_option_float (Preview *p, int option, float value)
+set_option_float (Preview * p, int option, float value)
 {
   const SANE_Option_Descriptor *opt;
   SANE_Handle dev;
@@ -504,7 +510,7 @@ set_option_float (Preview *p, int option, float value)
 }
 
 static void
-set_option_bool (Preview *p, int option, SANE_Bool value)
+set_option_bool (Preview * p, int option, SANE_Bool value)
 {
   SANE_Handle dev;
   SANE_Status status;
@@ -513,7 +519,8 @@ set_option_bool (Preview *p, int option, SANE_Bool value)
     return;
 
   dev = p->dialog->dev;
-  status = sane_control_option (dev, option, SANE_ACTION_SET_VALUE, &value, 0);
+  status =
+    sane_control_option (dev, option, SANE_ACTION_SET_VALUE, &value, 0);
   if (status != SANE_STATUS_GOOD)
     {
       DBG (DBG_fatal, "set_option_bool: sane_control_option failed: %s\n",
@@ -523,7 +530,7 @@ set_option_bool (Preview *p, int option, SANE_Bool value)
 }
 
 static int
-increment_image_y (Preview *p)
+increment_image_y (Preview * p)
 {
   size_t extra_size, offset;
   char buf[256];
@@ -532,8 +539,8 @@ increment_image_y (Preview *p)
   ++p->image_y;
   if (p->params.lines <= 0 && p->image_y >= p->image_height)
     {
-      offset = 3*p->image_width*p->image_height;
-      extra_size = 3*32*p->image_width;
+      offset = 3 * p->image_width * p->image_height;
+      extra_size = 3 * 32 * p->image_width;
       p->image_height += 32;
       p->image_data = realloc (p->image_data, offset + extra_size);
       if (!p->image_data)
@@ -560,6 +567,10 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
   SANE_Int len;
   int i, j;
 
+  DBG_INIT ();
+
+  DBG (DBG_debug, "input_available: enter\n");
+
   dev = p->dialog->dev;
   while (1)
     {
@@ -596,7 +607,7 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 	  scan_done (p);
 	  return;
 	}
-      if (!len) /* out of data for now */
+      if (!len)			/* out of data for now */
 	{
 	  if (p->input_tag < 0)
 	    {
@@ -618,7 +629,7 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 	      for (i = 0; i < len; ++i)
 		{
 		  u_char mask = buf[i];
-		  
+
 		  for (j = 7; j >= 0; --j)
 		    {
 		      u_char gl = (mask & (1 << j)) ? 0xff : 0x00;
@@ -649,7 +660,7 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 	      for (i = 0; i < len; ++i)
 		{
 		  p->image_data[p->image_offset++] = buf[i];
-		  if (p->image_offset%3 == 0)
+		  if (p->image_offset % 3 == 0)
 		    {
 		      if (++p->image_x >= p->image_width
 			  && increment_image_y (p) < 0)
@@ -660,10 +671,10 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 	    case 16:
 	      for (i = 0; i < len; ++i)
 		{
-		  guint16 value = buf [i];
+		  guint16 value = buf[i];
 		  if ((i % 2) == 1)
 		    p->image_data[p->image_offset++] = *(guint8 *) (&value);
-		  if (p->image_offset%6 == 0)
+		  if (p->image_offset % 6 == 0)
 		    {
 		      if (++p->image_x >= p->image_width
 			  && increment_image_y (p) < 0)
@@ -715,17 +726,14 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 	    case 16:
 	      for (i = 0; i < len; ++i)
 		{
-		  guint16 value = buf [i];
+		  guint16 value = buf[i];
 		  if ((i % 2) == 1)
 		    {
-		      p->image_data[p->image_offset++] = 
-			*(guint8 *) (&value);
-		      p->image_data[p->image_offset++] = 
-			*(guint8 *) (&value);
-		      p->image_data[p->image_offset++] = 
-			*(guint8 *) (&value);
+		      p->image_data[p->image_offset++] = *(guint8 *) (&value);
+		      p->image_data[p->image_offset++] = *(guint8 *) (&value);
+		      p->image_data[p->image_offset++] = *(guint8 *) (&value);
 		    }
-		  if (p->image_offset%2 == 0)
+		  if (p->image_offset % 2 == 0)
 		    {
 		      if (++p->image_x >= p->image_width
 			  && increment_image_y (p) < 0)
@@ -771,14 +779,14 @@ input_available (gpointer data, gint source, GdkInputCondition cond)
 		    return;
 		}
 	      break;
-	      
+
 	    case 16:
 	      for (i = 0; i < len; ++i)
 		{
-		  guint16 value = buf [i];
+		  guint16 value = buf[i];
 		  if ((i % 2) == 1)
 		    {
-		      p->image_data[p->image_offset] =  *(guint8 *) (&value);
+		      p->image_data[p->image_offset] = *(guint8 *) (&value);
 		      p->image_offset += 3;
 		    }
 		  if (p->image_offset % 2 == 0)
@@ -820,7 +828,7 @@ bad_depth:
 }
 
 static void
-scan_done (Preview *p)
+scan_done (Preview * p)
 {
   int i;
 
@@ -846,7 +854,7 @@ scan_done (Preview *p)
 }
 
 static void
-scan_start (Preview *p)
+scan_start (Preview * p)
 {
   SANE_Handle dev = p->dialog->dev;
   SANE_Status status;
@@ -859,7 +867,7 @@ scan_start (Preview *p)
   gtk_widget_set_sensitive (p->dialog->window->parent->parent->parent, FALSE);
 
   /* clear old preview: */
-  memset (p->preview_row, 0xff, 3*p->preview_width);
+  memset (p->preview_row, 0xff, 3 * p->preview_width);
   for (y = 0; y < p->preview_height; ++y)
     gtk_preview_draw_row (GTK_PREVIEW (p->window), p->preview_row,
 			  0, y, p->preview_width);
@@ -892,10 +900,9 @@ scan_start (Preview *p)
       return;
     }
 
-  if ((p->params.format >= SANE_FRAME_RGB && 
+  if ((p->params.format >= SANE_FRAME_RGB &&
        p->params.format <= SANE_FRAME_BLUE) &&
-      p->params.depth == 1 &&
-      p->params.pixels_per_line % 8 != 0)
+      p->params.depth == 1 && p->params.pixels_per_line % 8 != 0)
     {
       snprintf (buf, sizeof (buf),
 		"Can't handle unaligned 1 bit RGB or three-pass mode.");
@@ -903,7 +910,7 @@ scan_start (Preview *p)
       scan_done (p);
       return;
     }
-    
+
   p->image_offset = p->image_x = p->image_y = 0;
 
   if (p->params.format >= SANE_FRAME_RED
@@ -917,7 +924,7 @@ scan_start (Preview *p)
       if (p->image_data)
 	free (p->image_data);
 
-      p->image_width  = p->params.pixels_per_line;
+      p->image_width = p->params.pixels_per_line;
       p->image_height = p->params.lines;
       if (p->image_height < 0)
 	p->image_height = 32;	/* may have to adjust as we go... */
@@ -931,7 +938,7 @@ scan_start (Preview *p)
 	  scan_done (p);
 	  return;
 	}
-      memset (p->image_data, 0xff, 3*p->image_width*p->image_height);
+      memset (p->image_data, 0xff, 3 * p->image_width * p->image_height);
     }
 
   if (p->selection.active)
@@ -944,13 +951,15 @@ scan_start (Preview *p)
 
   if (sane_set_io_mode (dev, SANE_TRUE) == SANE_STATUS_GOOD
       && sane_get_select_fd (dev, &fd) == SANE_STATUS_GOOD)
-    p->input_tag = gdk_input_add (fd, GDK_INPUT_READ | GDK_INPUT_EXCEPTION, input_available, p);
+    p->input_tag =
+      gdk_input_add (fd, GDK_INPUT_READ | GDK_INPUT_EXCEPTION,
+		     input_available, p);
   else
     input_available (p, -1, GDK_INPUT_READ);
 }
 
 static void
-establish_selection (Preview *p)
+establish_selection (Preview * p)
 {
   float min, max, normal, dev_selection[4];
   int i;
@@ -966,10 +975,11 @@ establish_selection (Preview *p)
 	if (max >= INF)
 	  max = p->preview_width;
 
-	normal = 1.0/(((i == 0) ? p->preview_width : p->preview_height) - 1);
+	normal =
+	  1.0 / (((i == 0) ? p->preview_width : p->preview_height) - 1);
 	normal *= (max - min);
-	dev_selection[i]     = p->selection.coord[i]*normal + min;
-	dev_selection[i + 2] = p->selection.coord[i + 2]*normal + min;
+	dev_selection[i] = p->selection.coord[i] * normal + min;
+	dev_selection[i + 2] = p->selection.coord[i + 2] * normal + min;
       }
   for (i = 0; i < 4; ++i)
     set_option_float (p, p->dialog->well_known.coord[i], dev_selection[i]);
@@ -980,14 +990,14 @@ establish_selection (Preview *p)
 }
 
 static int
-make_preview_image_path (Preview *p, size_t filename_size, char *filename)
+make_preview_image_path (Preview * p, size_t filename_size, char *filename)
 {
   return gsg_make_path (filename_size, filename, 0, "preview-",
 			p->dialog->dev_name, ".ppm");
 }
 
 static void
-restore_preview_image (Preview *p)
+restore_preview_image (Preview * p)
 {
   u_int psurface_type, psurface_unit;
   char filename[PATH_MAX];
@@ -1009,8 +1019,7 @@ restore_preview_image (Preview *p)
      (e.g., consider an image whose first image byte is 13 (`\r').  */
   if (fscanf (in, "P6\n# surface: %g %g %g %g %u %u\n%d %d\n255%*[\n]",
 	      psurface + 0, psurface + 1, psurface + 2, psurface + 3,
-	      &psurface_type, &psurface_unit,
-	      &width, &height) != 8)
+	      &psurface_type, &psurface_unit, &width, &height) != 8)
     return;
 
   if (GROSSLY_DIFFERENT (psurface[0], p->surface[0])
@@ -1025,19 +1034,19 @@ restore_preview_image (Preview *p)
   p->image_height = height;
   if ((width == 0) || (height == 0))
     return;
-  p->image_data = malloc (3*width*height);
+  p->image_data = malloc (3 * width * height);
   if (!p->image_data)
     return;
 
-  nread = fread (p->image_data, 3, width*height, in);
+  nread = fread (p->image_data, 3, width * height, in);
 
-  p->image_y = nread/width;
-  p->image_x = nread%width;
+  p->image_y = nread / width;
+  p->image_x = nread % width;
 }
 
 /* This is executed _after_ the gtkpreview's expose routine.  */
 static gint
-expose_handler (GtkWidget *window, GdkEvent *event, gpointer data)
+expose_handler (GtkWidget * window, GdkEvent * event, gpointer data)
 {
   Preview *p = data;
 
@@ -1047,7 +1056,7 @@ expose_handler (GtkWidget *window, GdkEvent *event, gpointer data)
 }
 
 static gint
-event_handler (GtkWidget *window, GdkEvent *event, gpointer data)
+event_handler (GtkWidget * window, GdkEvent * event, gpointer data)
 {
   Preview *p = data;
   int i, tmp;
@@ -1135,19 +1144,19 @@ event_handler (GtkWidget *window, GdkEvent *event, gpointer data)
 }
 
 static void
-start_button_clicked (GtkWidget *widget, gpointer data)
+start_button_clicked (GtkWidget * widget, gpointer data)
 {
   preview_scan (data);
 }
 
 static void
-cancel_button_clicked (GtkWidget *widget, gpointer data)
+cancel_button_clicked (GtkWidget * widget, gpointer data)
 {
   scan_done (data);
 }
 
 static void
-top_destroyed (GtkWidget *widget, gpointer call_data)
+top_destroyed (GtkWidget * widget, gpointer call_data)
 {
   Preview *p = call_data;
 
@@ -1155,7 +1164,7 @@ top_destroyed (GtkWidget *widget, gpointer call_data)
 }
 
 Preview *
-preview_new (GSGDialog *dialog)
+preview_new (GSGDialog * dialog)
 {
   static int first_time = 1;
   GtkWidget *table, *frame;
@@ -1200,7 +1209,7 @@ preview_new (GSGDialog *dialog)
 		      /* padding */ 0);
 
   /* the empty box in the top-left corner */
-  frame = gtk_frame_new (/* label */ 0);
+  frame = gtk_frame_new ( /* label */ 0);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
   gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
 		    GTK_FILL, GTK_FILL, 0, 0);
@@ -1223,8 +1232,7 @@ preview_new (GSGDialog *dialog)
 			 GDK_EXPOSURE_MASK |
 			 GDK_POINTER_MOTION_MASK |
 			 GDK_POINTER_MOTION_HINT_MASK |
-			 GDK_BUTTON_PRESS_MASK |
-			 GDK_BUTTON_RELEASE_MASK);
+			 GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
   gtk_signal_connect (GTK_OBJECT (p->window), "event",
 		      (GtkSignalFunc) event_handler, p);
   gtk_signal_connect_after (GTK_OBJECT (p->window), "expose_event",
@@ -1254,7 +1262,7 @@ preview_new (GSGDialog *dialog)
   gtk_signal_connect_object (GTK_OBJECT (p->window), "motion_notify_event",
 			     signal_func, GTK_OBJECT (p->vruler));
 
-  p->viewport = gtk_frame_new (/* label */ 0);
+  p->viewport = gtk_frame_new ( /* label */ 0);
   gtk_frame_set_shadow_type (GTK_FRAME (p->viewport), GTK_SHADOW_IN);
   gtk_container_add (GTK_CONTAINER (p->viewport), p->window);
 
@@ -1297,7 +1305,7 @@ preview_new (GSGDialog *dialog)
 }
 
 void
-preview_update (Preview *p)
+preview_update (Preview * p)
 {
   float val, width, height, max_width, max_height;
   const SANE_Option_Descriptor *opt;
@@ -1352,16 +1360,16 @@ preview_update (Preview *p)
 
   /* guess the initial preview window size: */
 
-  width  = p->surface[GSG_BR_X] - p->surface[GSG_TL_X];
+  width = p->surface[GSG_BR_X] - p->surface[GSG_TL_X];
   height = p->surface[GSG_BR_Y] - p->surface[GSG_TL_Y];
   if (p->surface_type == SANE_TYPE_INT)
     {
-      width  += 1.0;
+      width += 1.0;
       height += 1.0;
     }
   else
     {
-      width  += SANE_UNFIX (1.0);
+      width += SANE_UNFIX (1.0);
       height += SANE_UNFIX (1.0);
     }
 
@@ -1370,46 +1378,46 @@ preview_update (Preview *p)
   if (width >= INF || height >= INF)
     p->aspect = 1.0;
   else
-    p->aspect = width/height;
+    p->aspect = width / height;
 
   if (surface_changed)
     {
-      max_width  = 0.5 * gdk_screen_width();
-      max_height = 0.5 * gdk_screen_height();
+      max_width = 0.5 * gdk_screen_width ();
+      max_height = 0.5 * gdk_screen_height ();
     }
   else
     {
-      max_width  = p->window->allocation.width;
+      max_width = p->window->allocation.width;
       max_height = p->window->allocation.height;
     }
 
   if (p->surface_unit != SANE_UNIT_PIXEL)
     {
-      width  = max_width;
+      width = max_width;
       height = width / p->aspect;
 
       if (height > max_height)
 	{
 	  height = max_height;
-	  width  = height * p->aspect;
+	  width = height * p->aspect;
 	}
     }
   else
     {
       if (width > max_width)
-	width  = max_width;
+	width = max_width;
 
       if (height > max_height)
 	height = max_height;
     }
 
   /* re-adjust so we maintain aspect without exceeding max size: */
-  if (width/height != p->aspect)
+  if (width / height != p->aspect)
     {
       if (p->aspect > 1.0)
-	height = width/p->aspect;
+	height = width / p->aspect;
       else
-	width  = height*p->aspect;
+	width = height * p->aspect;
     }
 
   p->preview_width = width + 0.5;
@@ -1428,7 +1436,7 @@ preview_update (Preview *p)
 }
 
 void
-preview_scan (Preview *p)
+preview_scan (Preview * p)
 {
   float min, max, swidth, sheight, width, height, dpi = 0;
   const SANE_Option_Descriptor *opt;
@@ -1450,25 +1458,25 @@ preview_scan (Preview *p)
       opt = sane_get_option_descriptor (p->dialog->dev,
 					p->dialog->well_known.dpi);
 
-      gwidth  = p->preview_width;
+      gwidth = p->preview_width;
       gheight = p->preview_height;
 
       height = gheight;
-      width  = height*p->aspect;
+      width = height * p->aspect;
       if (width > gwidth)
 	{
-	  width  = gwidth;
-	  height = width/p->aspect;
+	  width = gwidth;
+	  height = width / p->aspect;
 	}
 
       swidth = (p->surface[GSG_BR_X] - p->surface[GSG_TL_X]);
       if (swidth < INF)
-	dpi = MM_PER_INCH*width/swidth;
+	dpi = MM_PER_INCH * width / swidth;
       else
 	{
 	  sheight = (p->surface[GSG_BR_Y] - p->surface[GSG_TL_Y]);
 	  if (sheight < INF)
-	    dpi = MM_PER_INCH*height/sheight;
+	    dpi = MM_PER_INCH * height / sheight;
 	  else
 	    dpi = 18.0;
 	}
@@ -1493,7 +1501,7 @@ preview_scan (Preview *p)
 }
 
 void
-preview_destroy (Preview *p)
+preview_destroy (Preview * p)
 {
   char filename[PATH_MAX];
   FILE *out;
@@ -1512,7 +1520,7 @@ preview_destroy (Preview *p)
 		   p->surface[0], p->surface[1], p->surface[2], p->surface[3],
 		   p->surface_type, p->surface_unit,
 		   p->image_width, p->image_height);
-	  fwrite (p->image_data, 3, p->image_width*p->image_height, out);
+	  fwrite (p->image_data, 3, p->image_width * p->image_height, out);
 	  fclose (out);
 	}
     }
